@@ -2,13 +2,15 @@
 #' @description Lists names of dataset from eurostat with the particular
 #' pattern in the description.
 #' @details Downloads list of all datasets available on
-#' eurostat and return list of names of datasets that contains particular 
+#' eurostat and return list of names of datasets that contains particular
 #' pattern in the dataset description. E.g. all datasets related to
 #' education of teaching.
-#' @param pattern Character, datasets, folder or tables with this pattern in 
+#' @param pattern Character, datasets, folder or tables with this pattern in
 #'  	  the description will be returned (depending on the 'type' argument)
-#' @param type Grep the Eurostat table of contents either for 
-#'  	  'dataset' (default), 'folder', 'table' or "all" (for all types) .
+#' @param type Grep the Eurostat table of contents either for
+#'  	  'dataset' (default), 'folder', 'table' or "all" (for all types).
+#' @param fixed logical. If TRUE, pattern is a string to be matched as is.
+#'      Change to FALSE if more complex regex matching is needed.
 #' @return A tibble with eight columns
 #'    \itemize{
 #'  	\item{title}{The name of dataset of theme}
@@ -18,15 +20,21 @@
 #'    }
 #' @export
 #' @seealso \code{\link{get_eurostat}}, \code{\link{get_eurostat_toc}}
-#' @references See citation("eurostat") 
+#' @references See citation("eurostat")
 #' @author Przemyslaw Biecek and Leo Lahti \email{ropengov-forum@@googlegroups.com}
-#' @examples \dontrun{tmp <- search_eurostat("education"); head(tmp)}
+#' @examples \dontrun{
+#'   tmp <- search_eurostat("education")
+#'   head(tmp)
+#'   # Use "fixed = TRUE" when pattern has characters that would need escaping.
+#'   # Here, parentheses would normally need to be escaped in regex
+#'   tmp <- search_eurostat("Live births (total) by NUTS 3 region", fixed = TRUE)
+#' }
 #' @keywords utilities database
-search_eurostat <- function(pattern, type = "dataset") {
+search_eurostat <- function(pattern, type = "dataset", fixed = TRUE) {
   set_eurostat_toc()
   tmp <- get(".eurostatTOC", envir = .EurostatEnv)
   if (type != "all") tmp <- tmp[ tmp$type %in% type, ]
-  tmp[ grep(tmp$title, pattern = pattern), ]
+  tmp[ grep(tmp$title, pattern = pattern, fixed = fixed), ]
 }
 
 
@@ -35,4 +43,4 @@ search_eurostat <- function(pattern, type = "dataset") {
 grepEurostatTOC <- function(pattern, type = "dataset"){
   .Deprecated("search_eurostat")
   search_eurostat(pattern = pattern, type = type)
-}
\ No newline at end of file
+}
